@@ -164,7 +164,7 @@ struct nonblocking_fd *io_stream_get(struct io_backend *backend,
 {
 	NEW(stream_fd, f);
 
-	init_file(backend, &f->super, fd);
+	init_file(backend, &f->super, fd, NULL);
 	f->super.prepare = prepare_stream_fd;
 	f->super.read = stream_read_callback;
 	f->super.want_read = 1;
