@@ -40,7 +40,7 @@
 
 static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data)
 {
-	char *src;
+	unsigned char *src;
 	int left;
 	int pri;
 	time_t now = time(NULL);
